@@ -1,5 +1,6 @@
 """Plottng functions for visualizing distributions."""
 from __future__ import division
+import inspect
 import colorsys
 import numpy as np
 from scipy import stats
@@ -182,12 +183,22 @@ def boxplot(vals, groupby=None, names=None, join_rm=False, order=None,
     # Reshape and find labels for the plot
     vals, xlabel, ylabel, names = _box_reshape(vals, groupby, names, order)
 
-    # Draw the boxplot using matplotlib
-    boxes = ax.boxplot(vals, patch_artist=True, widths=widths, **kwargs)
-
     # Find plot colors
     colors, gray = _box_colors(vals, color, saturation)
 
+    # Make a flierprops dict and set symbol to override buggy default behavior
+    # on matplotlib 1.4.0
+    kwargs["sym"] = "d"
+
+    # Later versions of matplotlib only (but those are the one with the bug)
+    if "flierprops" in inspect.getargspec(ax.boxplot).args:
+        kwargs["flierprops"] = {"markerfacecolor": gray,
+                                "markeredgecolor": gray,
+                                "markersize": fliersize}
+
+    # Draw the boxplot using matplotlib
+    boxes = ax.boxplot(vals, patch_artist=True, widths=widths, **kwargs)
+
     # Set the new aesthetics
     for i, box in enumerate(boxes["boxes"]):
         box.set_color(colors[i])
@@ -205,6 +216,9 @@ def boxplot(vals, groupby=None, names=None, join_rm=False, order=None,
     for i, med in enumerate(boxes["medians"]):
         med.set_color(gray)
         med.set_linewidth(linewidth)
+
+    # As of matplotlib 1.4.0 there is a bug where these values are being
+    # ignored, so this is redundant with what's above but I am keeping it
     for i, fly in enumerate(boxes["fliers"]):
         fly.set_color(gray)
         fly.set_marker("d")
@@ -745,6 +759,12 @@ def _statsmodels_bivariate_kde(x, y, bw, gridsize, cut, clip):
         bw = [x_bw, y_bw]
     elif np.isscalar(bw):
         bw = [bw, bw]
+
+    if isinstance(x, pd.Series):
+        x = x.values
+    if isinstance(y, pd.Series):
+        y = y.values
+
     kde = sm.nonparametric.KDEMultivariate([x, y], "cc", bw)
     x_support = _kde_support(x, kde.bw[0], gridsize, cut, clip[0])
     y_support = _kde_support(y, kde.bw[1], gridsize, cut, clip[1])
