@@ -35,7 +35,6 @@ _style_keys = (
 
     "image.cmap",
     "font.family",
-    "pdf.fonttype",
     "font.sans-serif",
     )
 
@@ -197,12 +196,11 @@ def axes_style(style=None, rc=None):
             "ytick.color": dark_gray,
             "axes.axisbelow": True,
             "image.cmap": "Greys",
-            "font.family": "sans-serif",
+            "font.family": ["sans-serif"],
             "font.sans-serif": ["Arial", "Liberation Sans",
                                 "Bitstream Vera Sans", "sans-serif"],
             "grid.linestyle": "-",
             "lines.solid_capstyle": "round",
-            "pdf.fonttype": 42,
             }
 
         # Set grid on or off
